==> tuia-advert-center-api-2.3.78-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertPatrolDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;

/**
 * @Description: 广告落地页数据巡查对象
 * @Author: chensong
 * @Create: 2018-10-22
 */
public class AdvertPatrolDto implements Serializable {

    private static final long serialVersionUID = 8347675022277100895L;

    /**
     * 广告落地页链接类型
     */
    public static final int ADVERT_PROMOTE_URL_TYPE = 1;

    /**
     * 落地页内的跳转链接类型
     */
    public static final int JUMP_PROMOTE_URL_TYPE = 2;

    /**
     * 广告主id
     */
    private Long advertiserId;

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 落地页url
     */
    private String promoteUrl;

    /**
     * AE名称
     */
    private String aeName;

    /**
     * AE id
     */
    private Long aeId;

    /**
     * 销售名称
     */
    private String sellName;

    /**
     * 销售id
     */
    private Long sellId;

    /**
     * 广告主名称
     */
    private String companyName;

    /**
     * 巡查链接类型 1-落地页 2-跳转链接
     */
    private int promoteType;

    /**
     * 行业标签
     */
    private String tradeTagNum;

    /**
     * 一级代理商id
     */
    private Long agentId;

    /**
     * 直属代理商id
     */
    private Long directAgentId;

    /**
     * 广告类型
     */
    private Integer advertType;

    /**
     * 有效状态.
     */
    private Integer validStatus;

    public Long getAdvertiserId() {
        return advertiserId;
    }

    public void setAdvertiserId(Long advertiserId) {
        this.advertiserId = advertiserId;
    }

    public String getTradeTagNum() {
        return tradeTagNum;
    }

    public void setTradeTagNum(String tradeTagNum) {
        this.tradeTagNum = tradeTagNum;
    }

    public int getPromoteType() {
        return promoteType;
    }

    public void setPromoteType(int promoteType) {
        this.promoteType = promoteType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Long getDirectAgentId() {
        return directAgentId;
    }

    public void setDirectAgentId(Long directAgentId) {
        this.directAgentId = directAgentId;
    }
}

==> tuia-advert-center-api-2.4.51-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertPatrolDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;

/**
 * @Description: 广告落地页数据巡查对象
 * @Author: chensong
 * @Create: 2018-10-22
 */
public class AdvertPatrolDto implements Serializable {

    private static final long serialVersionUID = 8347675022277100895L;


    /**
     * 广告落地页链接类型
     */
    public static final int ADVERT_PROMOTE_URL_TYPE = 0;

    /**
     * 二跳落地页
     */
    public static final int JUMP_PROMOTE_URL_TYPE = 1;

    /**
     * 广告主id
     */
    private Long advertiserId;

    /**
     * 广告ID
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 落地页url
     */
    private String promoteUrl;

    /**
     * AE名称
     */
    private String aeName;

    /**
     * AE id
     */
    private Long aeId;

    /**
     * 销售名称
     */
    private String sellName;

    /**
     * 销售id
     */
    private Long sellId;

    /**
     * 广告主名称
     */
    private String companyName;

    //落地页ID
    private Long landPageId;

    /**
     * 巡查链接类型 0-落地页;1-二次跳转页面;2-配置落地页;3-ABTest落地页;4-素材绑定落地页;5-新媒体落地页
     */
    private int promoteType;

    /**
     * 行业标签
     */
    private String tradeTagNum;

    /**
     * 一级代理商id
     */
    private Long agentId;

    /**
     * 一级代理商名称
     */
    private String oneAgentName;

    /**
     * 直属代理商id
     */
    private Long directAgentId;

    /**
     * 广告类型
     */
    private Integer advertType;

    /**
     * 有效状态.
     */
    private Integer validStatus;

    public Long getAdvertiserId() {
        return advertiserId;
    }

    public void setAdvertiserId(Long advertiserId) {
        this.advertiserId = advertiserId;
    }

    public String getTradeTagNum() {
        return tradeTagNum;
    }

    public void setTradeTagNum(String tradeTagNum) {
        this.tradeTagNum = tradeTagNum;
    }

    public int getPromoteType() {
        return promoteType;
    }

    public void setPromoteType(int promoteType) {
        this.promoteType = promoteType;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Long getDirectAgentId() {
        return directAgentId;
    }

    public void setDirectAgentId(Long directAgentId) {
        this.directAgentId = directAgentId;
    }

    public String getOneAgentName() {
        return oneAgentName;
    }

    public void setOneAgentName(String oneAgentName) {
        this.oneAgentName = oneAgentName;
    }

    public Long getLandPageId() {
        return landPageId;
    }

    public void setLandPageId(Long landPageId) {
        this.landPageId = landPageId;
    }
}
